ErrorCode

Enum ErrorCode 

#[repr(u8)]
pub enum ErrorCode { InvalidArgument = 1, Unauthenticated = 2, PermissionDenied = 3, NotFound = 4, FailedPrecondition = 5, Unavailable = 6, DeadlineExceeded = 7, ResourceExhausted = 8, Cancelled = 9, ProtocolError = 10, Internal = 11, AlreadyExists = 12, }
Stable wire error codes whose discriminants are part of protocol version 3.

Variants



InvalidArgument = 1



Unauthenticated = 2



PermissionDenied = 3



NotFound = 4



FailedPrecondition = 5



Unavailable = 6



DeadlineExceeded = 7



ResourceExhausted = 8

Covers admission, capacity, queue, and size limits.



Cancelled = 9



ProtocolError = 10

A peer violated the wire protocol or state-machine contract.



Internal = 11

A local invariant or task failed without a peer protocol violation.



AlreadyExists = 12